
-- return the window size
function getWindowSize()
	return 640, 190
end

-- return the main font
-- the return is a list of font filename and size options
-- the first one found will be used
function getFont()
	if isMac then
		return { { name="GillSans.dfont", size=14 }, { name="Monaco.dfont", size=12 } }
	else
		return { { name="tahoma.ttf", size=14 }, { name="arial.ttf", size=12 } }
	end
end
-- return the label font
function getLabelFont()
	if isMac then
		return { { name="GillSans.dfont", size=11 }, { name="Monaco.dfont", size=9 } }
	else
		return { { name="tahoma.ttf", size=11 }, { name="arial.ttf", size=9 } }
	end
end
-- return the text field font
function getTextFieldFont()
	if isMac then
		return { { name="GillSans.dfont", size=12 }, { name="Monaco.dfont", size=10 } }
	else
		return { { name="tahoma.ttf", size=12 }, { name="arial.ttf", size=10 } }
	end
end

-- create and lay out all the controls
function createUI()

	-- load textures
	if isWin then
		atlas = texture( getResourceID( "buttons.png" ) )
		background = texture( getResourceID( "background.png" ) )
	else
		atlas = texture( "buttons.png" )
		background = texture( "background.png" )
	end
	setBackgroundTexture( background )

	local windowW = getWindowSize()
	
	-- set location of the banner
	setBannerPosition( 170.0 )
	
	-- set outline colours for groups
	setGroupActiveColour( 0.95, 0.9, 0.9, 1.0 )
	setGroupInactiveColour( 0.8, 0.4, 0.01, 1.0 )
	
	-- constants
	local pad = 10.0
	local kMeterW = 5
	local kMeterH = 69
	local kTriggerLvlPadH = 4.0
	local kMeterDrop = 14.0
	local kMeterPadH = 2.0
	local kPitchButtonW = 16
	local kPitchButtonH = 14
	local kTextFieldH = 12
	local kKnobSize = 42
	local kKnobSpace = 54
	local kEditTextH = 11
	local kSmallKnobSize = 16
	local kButtonW = 48
	local kButtonH = 32
	local kButtonSpaceH = 58
	local kButtonSpaceV = 42
		
	-- make renderers
	theKnobRenderer = knobRenderer( atlas, 6*kButtonW+1, 2*kButtonH+1, kKnobSize )
	theButtonRenderer = buttonRenderer( atlas )
	theSliderRenderer = sliderRenderer( atlas )

	-- buttons
	
	miscButtonsGroup = group( "Misc" )
	miscButtonsGroup:add( button( "Prefs", "Prefs",			0*kButtonSpaceH, 0, kButtonW, kButtonH, 0*kButtonW, 0*kButtonH ) )
	miscButtonsGroup:add( paramButton( "Digital Mode",		1*kButtonSpaceH, 0, kButtonW, kButtonH, 1*kButtonW, 0*kButtonH ) )
	miscButtonsGroup:add( paramButton( "Reverse",			2*kButtonSpaceH, 0, kButtonW, kButtonH, 2*kButtonW, 2*kButtonH ) )
	miscButtonsGroup:add( paramButton( "Stop",				3*kButtonSpaceH, 0, kButtonW, kButtonH, 9*kButtonW, 2*kButtonH ) )
	
	-- knobs
	
	local function knobAndTextField( group, param, label, x, y, size, textH, textW )
		textW = textW or size
		local knobx = x + 0.5 * ( textW - size )
		group:add( knob( param, "", knobx, y+textH+1, size ) )
		group:add( textField( param, label, x, y, textW, textH ) )
	end
	
	filterGroup = group( "Filter" )
	knobAndTextField( filterGroup, "Filter Cutoff", 	"Cutoff", 		0*kKnobSpace, 0, kKnobSize, kTextFieldH )
	knobAndTextField( filterGroup, "Filter Q", 			"Q", 			1*kKnobSpace, 0, kKnobSize, kTextFieldH )
	knobAndTextField( filterGroup, "Filter Type", 		"Type", 		2*kKnobSpace, 0, kKnobSize, kTextFieldH )
	knobAndTextField( filterGroup, "Filter LFO Speed", 	"LFO Speed", 	3*kKnobSpace, 0, kKnobSize, kTextFieldH )
	knobAndTextField( filterGroup, "Filter LFO Depth", 	"LFO Depth", 	4*kKnobSpace, 0, kKnobSize, kTextFieldH )
	knobAndTextField( filterGroup, "Saturation", 		"", 			5*kKnobSpace, 0, kKnobSize, kTextFieldH )
	knobAndTextField( filterGroup, "Saturation Shape", 	"Shape", 		6*kKnobSpace, 0, kKnobSize, kTextFieldH )
	
	masterLevelGroup = group( "Master" )
	knobAndTextField( masterLevelGroup, "Master feedback", "Feedback", 0*kKnobSpace, 0, kKnobSize, kTextFieldH )
	
	-- pitch controls
	
	pitchSliderGroup = group( "Pitch" )
	
	knobAndTextField( pitchSliderGroup, "Pitch LFO Speed", 	"LFO Speed", 0*kKnobSpace, 0, kKnobSize, kTextFieldH )
	knobAndTextField( pitchSliderGroup, "Pitch LFO Depth", 	"LFO Depth", 1*kKnobSpace, 0, kKnobSize, kTextFieldH )
	
	local kSmallIndicatorSpace = 20
	
	-- envelope controls
	
	fadeGroup = group( "Fade" )
	local kFadeTextW = 36
	local kFadeTextSpace = 42
	knobAndTextField( fadeGroup, "Env Attack", 	"", 	0, 0, kSmallKnobSize, kTextFieldH, kFadeTextW )
	knobAndTextField( fadeGroup, "Env Release",	"", 	kFadeTextSpace, 0, kSmallKnobSize, kTextFieldH, kFadeTextW )
	fadeGroup:add( dropDown( "Auto Clear After Fade",	2*kFadeTextSpace, 0, 48, 12 ) )
	fadeGroup:add( paramButton( "Env Gate",				2*kFadeTextSpace+kButtonSpaceH, 0, kButtonW, kButtonH, 0*kButtonW, 2*kButtonH ) )
	fadeGroup:add( paramButton( "Env Override",			2*kFadeTextSpace+2*kButtonSpaceH, 0, kButtonW, kButtonH, 9*kButtonW, 0*kButtonH ) )
	
	-- positions!
	
	local left = 20.0
	local ight = windowW - 20.0
	
	local x = left
	local y = left
	
	local theValueDisplay = valueDisplay()
	theValueDisplay:setColour( 1, 1, 1, 1 )
	
	fadeGroup:setPosition( x, y )
	theValueDisplay:setPosition( "EnvLevel", x+2*kFadeTextSpace, y+kSmallIndicatorSpace, 48, 12 )
	x = x + fadeGroup:width() + pad
	
	miscButtonsGroup:setPosition( x, y )
	add( indicator( "DigitalModeActive", x+1*kButtonSpaceH, y+1*kButtonSpaceV-6, 48, 12, 5*kButtonW, 4*kButtonH ) )
	x = x + miscButtonsGroup:width() + pad
	
	theValueDisplay:setPosition( "Tempo", x, y+22, kKnobSize+10, 12 )
	theValueDisplay:setPosition( "DelayTime", x, y-10, kKnobSize+10, 12 )
	theValueDisplay:setPosition( "DelayBeats", x, y+6, kKnobSize+10, 12 )

	x = left
	y = y + fadeGroup:height() + pad + 10
	filterGroup:setPosition( x, y )
	add( paramButton( "Saturation On/Off", x+5*kKnobSpace+0.5*(kKnobSize-48), y-16, 48, 12, 4*kButtonW, 4*kButtonH ) )
		x = x + filterGroup:width() + pad

	masterLevelGroup:setPosition( x, y )	
	x = x + masterLevelGroup:width() + pad
	
	pitchSliderGroup:setPosition( x, y )
	x = x + pitchSliderGroup:width() + pad
	levelsX = x
	levelsY = y - kMeterDrop
		
	-- positions done
	
	-- meters
	
	x = levelsX
	y = levelsY
	x = x - 12
	
	meters = levelMeters( atlas, 512-5, 0, kMeterW, kMeterH )
	meters:add( "InputRmsLeft", x, y )
	x = x + kMeterW
	meters:add( "InputRmsRight", x, y )
	x = x + kMeterW
	x = x + 2*kMeterPadH
	meters:add( "FxRmsLeft", x, y )
	x = x + kMeterW
	meters:add( "FxRmsRight", x, y )

end		-- of createUI()
