
-- return the window size
function getWindowSize()
	return 290, 100
end

-- return the main font
-- the return is a list of font filename and size options
-- the first one found will be used
function getFont()
	if isMac then
		return { { name="GillSans.dfont", size=14 }, { name="Monaco.dfont", size=12 } }
	else
		return { { name="tahoma.ttf", size=14 }, { name="arial.ttf", size=12 } }
	end
end
-- return the label font
function getLabelFont()
	if isMac then
		return { { name="GillSans.dfont", size=11 }, { name="Monaco.dfont", size=9 } }
	else
		return { { name="tahoma.ttf", size=11 }, { name="arial.ttf", size=9 } }
	end
end
-- return the text field font
function getTextFieldFont()
	if isMac then
		return { { name="GillSans.dfont", size=12 }, { name="Monaco.dfont", size=10 } }
	else
		return { { name="tahoma.ttf", size=12 }, { name="arial.ttf", size=10 } }
	end
end

-- create and lay out all the controls
function createUI()

	-- load textures
	if isWin then
		atlas = texture( getResourceID( "buttons.png" ) )
		background = texture( getResourceID( "background.png" ) )
	else
		atlas = texture( "buttons.png" )
		background = texture( "background.png" )
	end
	setBackgroundTexture( background )

	local windowW = getWindowSize()
	
	-- set location of the banner
	setBannerPosition( 80.0, false )
	
	-- set outline colours for groups
	setGroupActiveColour( 0.95, 0.9, 0.9, 1.0 )
	setGroupInactiveColour( 0.8, 0.4, 0.01, 1.0 )
	
	-- constants
	local kTextFieldH = 12
	local kKnobSize = 42
	local kKnobSpace = 54
	local kButtonW = 48
	local kButtonH = 12
	local kButtonSpaceH = 52
	local kButtonU = 49
		
	-- make renderers
	theKnobRenderer = knobRenderer( atlas, 5*kButtonU, 0, kKnobSize )
	theButtonRenderer = buttonRenderer( atlas )

	-- controls
	
	local x = 20
	local y = 20

	add( button( "Prefs", "Prefs",		x, 40, kButtonW, kButtonH, 4*kButtonU, 0 ) )

	add( paramButton( "Tap Record",		x, y, kButtonW, kButtonH, 0*kButtonU, 0 ) )
	x = x + kButtonSpaceH
	add( paramButton( "Freeze Loop",	x, y, kButtonW, kButtonH, 1*kButtonU, 0 ) )
	x = x + kButtonSpaceH
	add( paramButton( "Reverse",		x, y, kButtonW, kButtonH, 2*kButtonU, 0 ) )
	x = x + kButtonSpaceH
	add( paramButton( "Triplet",		x, y, kButtonW, kButtonH, 3*kButtonU, 0 ) )
	x = x + kButtonSpaceH
	
	local function knobAndTextField( param, label, x, y, size, textH, textW )
		textW = textW or size
		local knobx = x + 0.5 * ( textW - size )
		add( knob( param, "", knobx, y+textH+1, size ) )
		add( textField( param, label, x, y, textW, textH ) )
	end
	
	knobAndTextField( "Master feedback", "Feedback", x, y, kKnobSize, kTextFieldH )

end		-- of createUI()
